Welcome to Pywr’s documentation! — Pywr 0.5dev documentation

# Welcome to Pywr’s documentation!

Pywr is a generalised network resource allocation model written in Python. It intends to be fast, free and extendible.

Contents:

- Installing Pywr
  - Dependencies
  - Installing (in general)
  - Installing binary packages with Anaconda
  - Installing from source with Anaconda
  - Installing on Windows
  - Installing on Linux
  - Installing on OS X
  - Development and testing
- Tutorial
  - A minimal example
- Problem formulation
- JSON model format
  - Overview of document structure
  - Metadata
  - Timestepper
  - Solver
  - Nodes
  - Edges
  - Parameters
  - Debugging and syntax errors
  - Footnotes
- Cookbook
  - Demand restrictions
  - External data
  - Aggregated parameters
- Python API reference
  - pywr.optimisation package
  - Parameters
  - Recorders
  - pywr.domains package
  - pywr.solvers package
  - Notebook Utilities
- License
  - Software
  - Documentation